@@ -1,10 +1,9 @@
 /*************************************************
 * Win32 Timer Source File                        *
-* (C) 1999-2005 The Botan Project                *
+* (C) 1999-2007 The Botan Project                *
 *************************************************/
 
 #include <botan/tm_win32.h>
-#include <botan/util.h>
 #include <windows.h>
 
 namespace Botan {
@@ -14,9 +13,9 @@ namespace Botan {
 *************************************************/
 u64bit Win32_Timer::clock() const
    {
-   FILETIME tv;
-   GetSystemTimeAsFileTime(&tv);
-   return combine_timers(tv.dwHighDateTime, tv.dwLowDateTime, 10000000);
+   LARGE_INTEGER tv;
+   ::QueryPerformanceCounter(&tv);
+   return tv.QuadPart;
    }
 
 }
